@@ -396,10 +396,13 @@ def open_pipe(command, stdin=None, stdout=None, stderr=None):
 
   # Quote only the arguments on Windows.  Later versions of subprocess,
   # 2.5.2+ confirmed, don't require this quoting, but versions < 2.4.3 do.
-  if (sys.platform == 'win32'):
+  if sys.platform == 'win32':
     args = command[1:]
     args = ' '.join([_quote_arg(x) for x in args])
     command = command[0] + ' ' + args
+    command_string = command
+  else:
+    command_string = ' '.join(command)
 
   if not stdin:
     stdin = subprocess.PIPE
@@ -413,7 +416,7 @@ def open_pipe(command, stdin=None, stdout=None, stderr=None):
                        stdout=stdout,
                        stderr=stderr,
                        close_fds=not windows)
-  return p.stdin, p.stdout, p.stderr, (p, command)
+  return p.stdin, p.stdout, p.stderr, (p, command_string)
 
 def wait_on_pipe(waiter, binary_mode, stdin=None):
   """Waits for KID (opened with open_pipe) to finish, dying
@@ -423,7 +426,7 @@ def wait_on_pipe(waiter, binary_mode, stdin=None):
   if waiter is None:
     return
 
-  kid, command = waiter
+  kid, command_string = waiter
   stdout, stderr = kid.communicate(stdin)
   exit_code = kid.returncode
 
@@ -437,7 +440,11 @@ def wait_on_pipe(waiter, binary_mode, stdin=None):
   stderr_lines = stderr.splitlines(True)
 
   if exit_code < 0:
-    exit_signal = os.WTERMSIG(-exit_code)
+    if not windows:
+      exit_signal = os.WTERMSIG(-exit_code)
+    else:
+      exit_signal = exit_code
+
     if stdout_lines is not None:
       sys.stdout.write("".join(stdout_lines))
     if stderr_lines is not None:
@@ -445,12 +452,12 @@ def wait_on_pipe(waiter, binary_mode, stdin=None):
     if verbose_mode:
       # show the whole path to make it easier to start a debugger
       sys.stderr.write("CMD: %s terminated by signal %d\n"
-                       % (' '.join(command), exit_signal))
+                       % (command_string, exit_signal))
     raise SVNProcessTerminatedBySignal
   else:
     if exit_code and verbose_mode:
       sys.stderr.write("CMD: %s exited with %d\n"
-                       % (' '.join(command), exit_code))
+                       % (command_string, exit_code))
     return stdout_lines, stderr_lines, exit_code
 
 # Run any binary, supplying input text, logging the command line
@@ -1031,13 +1038,15 @@ class Sandbox:
     ### TODO: Move this into to the build() method
     # For dav tests we need a single authz file which must be present,
     # so we recreate it each time a sandbox is created with some default
-    # contents.
+    # contents, making sure that an empty file is never present
     if self.repo_url.startswith("http"):
       # this dir doesn't exist out of the box, so we may have to make it
       if not os.path.exists(work_dir):
         os.makedirs(work_dir)
       self.authz_file = os.path.join(work_dir, "authz")
-      file_write(self.authz_file, "[/]\n* = rw\n")
+      tmp_authz_file = os.path.join(work_dir, "authz-" + self.name)
+      open(tmp_authz_file, 'w').write("[/]\n* = rw\n")
+      shutil.move(tmp_authz_file, self.authz_file)
 
     # For svnserve tests we have a per-repository authz file, and it
     # doesn't need to be there in order for things to work, so we don't
